=== modified file 'lib/lp/registry/windmill/tests/test_yuitests.py'
--- lib/lp/registry/windmill/tests/test_yuitests.py	2010-03-22 22:35:05 +0000
+++ lib/lp/registry/windmill/tests/test_yuitests.py	2010-03-29 20:29:11 +0000
@@ -9,6 +9,8 @@
 import re
 import unittest
 
+from windmill.authoring import WindmillTestClient
+
 from canonical.config import config
 from canonical.launchpad.windmill.testing import constants
 
@@ -16,28 +18,60 @@
 from lp.testing import WindmillTestCase
 
 
-class TestRegistryYUIUnitTests(WindmillTestCase):
+class YUIUnitTestCase(WindmillTestCase):
 
     layer = RegistryWindmillLayer
     suite_name = 'RegistryYUIUnitTests'
-    log_pattern = re.compile(r'<pre id="python-log">\|\|(.*)</pre>')
-    view_name = u'/+yui-unittest/'
-    test_dir = u'canonical/launchpad/javascript'
-    test_path = test_dir + u'/registry/tests/milestone_table.html'
-
-    def test_YUITestFileView(self):
-        client = self.client
-        client.open(url=self.view_name + self.test_path)
-        client.waits.forPageLoad(timeout=constants.PAGE_LOAD)
-        client.waits.forElement(id='complete')
-        response = client.commands.getPageText()
-        match = self.log_pattern.search(response['result'])
-        lines = match.group(1).split('||')
-        for line in lines:
-            result, test_name, unit_test_name = line.split('::')
-            self.assertTrue('pass' == result,
-                'Failue in %s.%s' % (unit_test_name, test_name))
+
+    _yui_results = None
+    _log_pattern = re.compile(r'<pre id="python-log">\|\|(.*)</pre>')
+    _view_name = u'http://launchpad.dev:8085/+yui-unittest/'
+
+    def initialize(self, test_path):
+        self.test_path = test_path
+        self.yui_runner_url = self._view_name + test_path
+
+    def setUp(self):
+        super(YUIUnitTestCase, self).setUp()
+        if self._yui_results is None:
+            client = self.client
+            client.open(url=self.yui_runner_url)
+            client.waits.forPageLoad(timeout=constants.PAGE_LOAD)
+            client.waits.forElement(id='complete')
+            response = client.commands.getPageText()
+            match = self._log_pattern.search(response['result'])
+            self._yui_results = {}
+            lines = match.group(1).split('||')
+            for line in lines:
+                result, test_name, unit_test_name = line.split('::')
+                self._yui_results[test_name] = dict(
+                    result=result, message='oops',
+                    unit_test_name=unit_test_name)
+
+    def _verify_test(self, test_name):
+        if test_name not in self._yui_results:
+            self.fail("Test harness or js failed.")
+        result = self._yui_results[test_name]
+        self.assertTrue('pass' == result,
+                'Failue in %s.%s: %s' % (
+                    result['unit_test_name'], test_name, result['message']))
+
+    def runTest(self):
+        if self._yui_results is None:
+            self.fail("Test harness or js failed.")
+        for test_name in self._yui_results:
+            result = self._yui_results[test_name]
+            self.assertTrue('pass' == result['result'],
+                    'Failue in %s.%s: %s' % (
+                        result['unit_test_name'],
+                        test_name, result['message']))
 
 
 def test_suite():
-    return unittest.TestLoader().loadTestsFromName(__name__)
+    test_path = (
+        u'canonical/launchpad/javascript/registry/tests/milestone_table.html')
+    test_case = YUIUnitTestCase()
+    test_case.initialize(test_path)
+    suite = unittest.TestSuite()
+    suite.addTest(test_case)
+    return suite

